@@ -1,10 +1,10 @@
-__version__ = "0.3.28"
+__version__ = "0.3.30"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'dde95da2bb47b7b004898bf2e31da91d1ce26c2f'
-__git_head_subject__ = 'Finished release v0.3.28.'
+__git_head_hash__ = 'a38a847c6d586c069aef62d9aabc6360bdebc2ed'
+__git_head_subject__ = 'administrative privileges should not be required by default'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
